@@ -59,7 +59,7 @@ export @tags, @tags_noescape, m, css, Style, styles, render, Pretty, savehtml, s
 
 # Units
 include(joinpath(@__DIR__, "cssunits.jl"))
-export px, pt, em, #= (this one conflicts with Base) rem, =# vh, vw, vmin, vmax, pc
+export px, pt, em, #= (this one conflicts with Base) rem, =# vh, vw, vmin, vmax, pc, fr
 
 ## Basic definitions
 
@@ -130,7 +130,7 @@ function processattrs(ctx, tag, attrs)
     )
 end
 
-function flat(xs::Union{Base.Generator, Tuple, Array})
+function flat(xs::Union{Base.Generator, Tuple, AbstractArray})
     out = Any[] # Vector{Any} for node children and attribute values
     for x in xs
         append!(out, flat(x))
@@ -138,6 +138,7 @@ function flat(xs::Union{Base.Generator, Tuple, Array})
     out
 end
 flat(x) = (x,)
+flat(x::AbstractRange) = (x,)
 
 ## Rendering
 
@@ -178,8 +179,8 @@ printescaped(io::IO, x::AbstractChar, escapes) = printescaped(io, string(x), esc
 # allocation via sprint. future use: sprint(printescaped, x, escapes))
 printescaped(io::IO, x, escapes) = printescaped(io, sprint(print, x), escapes)
 
-# pass numbers through untrammelled
-kebab(camel::String) = join(islowercase(c) || isnumeric(c) || c == '-' ? c : '-' * lowercase(c) for c in camel)
+# pass numbers (and 1-character attributes) through untrammelled
+kebab(camel::String) = length(camel) > 1 ? join(islowercase(c) || isnumeric(c) || c == '-' ? c : '-' * lowercase(c) for c in camel) : camel
 
 
 ## HTMLSVG
@@ -238,7 +239,7 @@ renderdomchild(io, rctx::RenderContext, ctx, x::Nothing) = nothing
 # Render and escape other HTMLSVG children, including CSS nodes, in the parent context.
 # If a child is `showable` with text/html, render with that using `repr`.
 renderdomchild(io, rctx::RenderContext, ctx, x) = 
-    showable(MIME("text/html"), x) ? print(io, repr(MIME("text/html"), x)) : printescaped(io, x, escapechild(ctx))
+    showable(MIME("text/html"), x) ? show(io, MIME("text/html"), x) : printescaped(io, x, escapechild(ctx))
 
 # All camelCase attribute names from HTML 4, HTML 5, SVG 1.1, SVG Tiny 1.2, and SVG 2
 const HTML_SVG_CAMELS = Dict(lowercase(x) => x for x in [
